#
# spec file for package python-autopep8
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-autopep8
Version:        1.4.3
Release:        1.12
Summary:        Automatic generated to pep8 checked code
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hhatto/autopep8
Source:         https://files.pythonhosted.org/packages/source/a/autopep8/autopep8-%{version}.tar.gz
BuildRequires:  %{python_module pycodestyle >= 2.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-pycodestyle >= 2.4
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Autopep8 is automatic generated to pep8 checked code.
This is old style tool, wrapped pep8 via subprocess module.

%prep
%setup -q -n autopep8-%{version}
sed -i '1s/^#!.*//' autopep8.py # Remove she-bang line

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/autopep8

%check
export LANG="en_US.UTF-8"
%python_exec setup.py test -q

%pre
# Since /usr/bin/autopep8 became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/autopep8 ] || rm -f %{_bindir}/autopep8

%post
%python_install_alternative autopep8

%postun
%python_uninstall_alternative autopep8

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/autopep8
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/autopep8.py*
%{python_sitelib}/autopep8-%{version}-py%{python_version}.egg-info

%changelog
* Thu Nov 22 2018 arun@gmx.de
- update to version 1.4.3:
  * w605 fixes for identical tokens
  * fix e402 fixed method when import some modules (for #447)
  * use _is_binary_operator
  * (origin/fix-w503-more-corner-cases) fix w503 with comment into
    pointed out line (for #446)
* Tue Oct 30 2018 arun@gmx.de
- update to version 1.4.2:
  * strict autopep8
  * add test for w503 fixed method with empty line
  * fix IndexError in w503 fixed method
  * fix w504 with any other tokenize.OP
* Wed Oct 17 2018 arun@gmx.de
- specfile:
  * update requirement of pycodestyle to >= 2.4
- update to version 1.4.1:
  * update description for --exit-code option
  * add unit test for --exit-code option
  * fix fail test
  * use --exit-code option value
  * add --exit-code option
  * format .rst
  * update readme
  * fallback, use .pep8 config
  * update requirement, pycodestyle 2.4.0 and higher version
  * refactoring
  * not change import statement to top of file when duplicate import
  * pycodestyle & autopep8
  * enable reading the settings from '.flake8' file
  * change default config path
  * change: return exit-code 1 when exists diff output
  * work around exception for #403
  * fix w503 with into comments (for #411)
  * handling exception with case of line comment
  * remove debug print
  * unit test for w503 and w504 fixed methods
  * implementation W504 fixed method.
  * W50x are set to DEFAULT_IGNORE
  * update test suite data for e72x test
  * add test for get_module_imports_on_top_of_file
  * improve e402 fixed method
  * update test suite output
  * update method list
  * add E402 fixed method and test
* Mon Sep  3 2018 tchvatal@suse.com
- Install license
- Delete old archive
* Sat Sep  1 2018 arun@gmx.de
- update to version 1.4:
  * py37
  * W690 add DEFAULT_IGNORE. (because Python3 is mainstream now)
  * strict pep8
  * update readme
  * fix E702 is not running in case of README.rst example
  * add unit test for e128 with -aaa option
  * fix exception in fix_w503, when do not pointing out W503
  * fix E305, when E303 and E305 are detected on the subsequent line
  * env: PEP8_VERSION=pypi,github
  * Travis CI: Add Python 3.7 to the testing
  * update acid test output data
  * seperate to e113 and e116 fixed method
  * Update links to PyPI in README.rst
  * add W605 fixed method
  * add unit test for w605 fixed method
  * Make test_e225_with_indentation_fix() actually use the fixer for
    E225
  * Add fixer for E252 "Missing whitespace around parameter equals"
  * ix: case that W503 in a continuous 5 or more lines
  * add test case for W503 in a continuous 5 or more lines
  * fix e731 with case of default argument
  * add test for e731 with default arguments
  * fix broken coverage script
  * Handle ValueError from check_syntax
* Sun Apr  1 2018 arun@gmx.de
- update to version 1.3.5:
  * add pypi version badge
  * refactoring (strict pylint)
  * fix e713 and e714 chain cases
  * add test for e713 and e714 chain cases
  * avoid e265
  * add test for #389
  * fix e265 when starts non-alphanumeric symbols (#389)
  * Drop support for EOL Python 3.3
  * Remove redundant Python 2.6 code
  * Rewrite unnecessary list comprehension as dict comprehension
  * Rewrite unnecessary dict call as literal
  * Rewrite unnecessary list literal as set literal
  * Rewrite unnecessary generator as set comprehension
  * Rewrite unnecessary generator as set comprehension
  * Use automatic formatters (py2.7+)
  * Remove redundant Python 2.6 code
  * change: not affeted FF(FromFeed) in Reindenter
  * add unit test for #322
  * read flake8 config
* Sun Feb  4 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.3.4:
  * support in some more cases in E712
  * add test for e712 with dict value
  * drop support Python2.6
  * strict pylint
  * add to E133 fixed method and available hang-closing option
  * fix unit test
  * add E226 in default ignore code
  * change: use compile() with dont_inherit=True
  * add test, invalid config key for autopep8
  * print enable config section and key-value in verbose mode
  * add test for w602 valid and invalid 2to3 fixed case, skip now
* Thu Oct 12 2017 arun@gmx.de
- update to version 1.3.3:
  * add verbose print for 2to3 fixer (for #325)
  * fix test suite output
  * for #338 (easy solution...)
  * Fix a bug in E305
  * care of corner cases for E713 (maybe, not perfect)
  * ignore 'not in' case for E713
  * add test for e713 regression (for #276)
  * strict pep8
  * improve w503 fixed method
  * more test case for w503
  * consider that w503 with comment (#323)
  * add test that w503 with comment
  * Avoid a crash when shortening comments
* Fri Aug  4 2017 jmatejek@suse.com
- convert to singlespec (this incidentally fixes bsc#1047622 which
  affected the now dropped python3-autopep8)
- update requirement name from pep8 to pycodestyle
- update to 1.3.2
  * upstream provides no changelog
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to 1.1.1: no upstream changelog
- add -q to test to avoid spamming the build log
* Sat Nov  8 2014 ledest@gmail.com
- fix bashism in pre script
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 1.0.3
  + Upstream provides no changelog
* Fri May  9 2014 toddrme2178@gmail.com
- Update to 1.0.2:
  + Upstream provides no changelog
- Update to 1.0.1
- Update to 1.0.0
- Update to 0.9.7
- Update to 0.9.6
- Fix UnicodeDecodeError in unittests
* Fri Nov 15 2013 speilicke@suse.com
- Only ghost /etc/alternatives on 12.3 or newer
* Tue Nov  5 2013 speilicke@suse.com
- Update to version 0.9.5:
  + Upstream provides no changelog
- Run testsuite
- Implement update-alternatives
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Aug 21 2012 highwaystar.ru@gmail.com
- updated to version 0.7.3
- python3 package added
- spec improved
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.1.3
* Fri Jul  8 2011 saschpe@suse.de
- Initial version
